#-- 
#  Copyright (C) 2008 Red Hat Inc.
#  
#  This library is free software; you can redistribute it and/or
#  modify it under the terms of the GNU Lesser General Public
#  License as published by the Free Software Foundation; either
#  version 2.1 of the License, or (at your option) any later version.
#  
#  This library is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#  Lesser General Public License for more details.
#  
#  You should have received a copy of the GNU Lesser General Public
#  License along with this library; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
#
# Author: Bryan Kearney <bkearney@redhat.com>
#--

import "appliance_base"
#
# apache
# -----
# Sets up the apache web server
#

$APACHE_CONF_DIR = "/etc/httpd/conf.d"
$APACHE_HTML_DIR = "/var/www/html"
$APACHE_CGI_DIR = "/var/www/cgi-bin"

class apache inherits appliance_base {	
	# The following packages need to be installed
	#package {apache:			
	#	name => $operatingsystem ? {
	#			debian	=> "apache2",
	#			default	=> "httpd",
	#			},
	#	ensure		=> installed}	
	
	# The appliance base messes with the network, Make sure
	# we run after that
	service {"httpd":
		ensure	    => "running",
		enable 		=> true,
		require     => Service[network],
		hasstatus => "true",		
		#subscribe 	=> [Package[apache]]	
	}
}

include apache


define apache_proxyAJP($server = "localhost", 
							$port="8009",
							$targetContext)
{
	include apache 
	
	file_replacement{"add_ajp_proxy_pass":
				file	=> "$APACHE_CONF_DIR/proxy_ajp.conf",
				line	=> "ProxyPass    /$name ajp://$server:$port/$targetContext",
				#require	=> Package["apache"],
				notify  => Service[httpd]
	}
}

define apache_config_file($content="x", $source="x")
{
	include apache
	file {"$APACHE_CONF_DIR/$name":
			ensure => file,
			content => $content ? {x => undef, default => $content} ,
			source => $source ? {x => undef, default => $source},
			notify => Service["httpd"]
	}	
}

define apache_cgi_script($content="x", $source="x")
{
	include apache
	file {"$APACHE_CGI_DIR/$name":
			ensure => file,
			content => $content ? {x => undef, default => $content} ,
			source => $source ? {x => undef, default => $source},
			mode => "755"
	}	
}

define apache_htdigest($digest_file, $digest_username, $digest_password, $digest_realm="")
{
	file_append{"add_htdigest_for_$digest_username_in_$digest_realm":
				file	=> $digest_file,
				line	=> template("apache/digest_line.erb")
	}	
	
}
